@@ -11,15 +11,15 @@
 #include <unistd.h>
 
 #include "apolloron.h"
-#include "apolloron_html_client.h"
+#include "apolloron_http_client.h"
 
 using namespace apolloron;
-using namespace apolloron_html_client;
+using namespace apolloron_http_client;
 
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "1.0.4";
+const char *INKF_VERSION  = "1.0.6";
 const char *INKF_COPY     = "Copyright (C) 2002-2009 Tachibanamasashi";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -175,7 +175,7 @@ int main(int argc, char *argv[]) {
 #else
       if (!strncasecmp(option.input_filenames[i], "http://", 7)) {
 #endif
-        HTMLClient hc;
+        HTTPClient hc;
         tmp_str = hc.getURL(option.input_filenames[i]);
         strncpy(option.input_charset, hc.getOrigCharset().c_str(), 31);
         option.input_charset[31] = '\0';
