@@ -16,7 +16,7 @@ class Keys;
 
 /*! @brief Version of libapolloron.
  */
-#define LIBAPOLLORON_VERSION "0.43.6"
+#define LIBAPOLLORON_VERSION "0.43.7"
 
 
 /*----------------------------------------------------------------------------*/
@@ -213,6 +213,8 @@ public:
   virtual long search(const String &key, long pos = 0L) const;
   virtual long searchCase(const String &key, long pos = 0L) const;
   virtual long searchChar(const char c, long pos = 0L) const;
+  virtual String& replace(const String &key, const String &replace_str, long pos = 0L) const;
+  virtual String& replaceCase(const String &key, const String &replace_str, long pos = 0L) const;
 
   // Format
   virtual int sprintf(const char *format, ...);
