@@ -34,7 +34,13 @@ extern const char *STR_ISO8859_13;
 extern const char *STR_ISO8859_14;
 extern const char *STR_ISO8859_15;
 extern const char *STR_ISO8859_16;
+extern const char *STR_KOI8_R;
+extern const char *STR_KOI8_U;
+extern const char *STR_CP1251;
+extern const char *STR_CP1252;
 extern const char *STR_UTF8;
+extern const char *STR_UTF7;
+extern const char *STR_UTF7_IMAP;
 extern const char *STR_SJIS;
 extern const char *STR_JIS;
 extern const char *STR_EUCJP;
@@ -49,8 +55,8 @@ const char* auto_detect(const char* str);
 const char* jis_auto_detect(const char* str);
 char* iso8859_to_utf8(const char* str, int iso8859_num);
 char* utf8_to_iso8859(const char* str, int iso8859_num);
-char* koi8_to_utf8(const char* str, char ch);
-char* utf8_to_koi8(const char* str, char ch);
+char* europe_to_utf8(const char* str, char ch);
+char* utf8_to_europe(const char* str, char ch);
 char* utf8_to_eucjp(const char* str);
 char* sjis_to_eucjp(const char* str);
 char* jis_to_eucjp(const char* str);
